@@ -1,4 +1,5 @@
 import os.path
+import csv
 
 
 def relative_file(filename):
@@ -7,3 +8,10 @@ def relative_file(filename):
     pkgdir = os.path.join(thisdir, "..")
     newpath = os.path.join(pkgdir, filename)
     return os.path.abspath(newpath)
+
+
+def load_csv(filename):
+    with open(filename, "r", newline="") as fp:
+        r = csv.DictReader(fp)
+        for row in r:
+            yield row
